==> oceanbolt.sdk-0.2.1.tar.gz: oceanbolt.sdk-0.2.1/oceanbolt/com/fleetmanagement_v3/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.fleet_management_service import FleetManagementServiceClient
from .types.service import AddVesselRequest
from .types.service import BatchVesselsRequest
from .types.service import CreateFleetRequest
from .types.service import DeleteFleetRequest
from .types.service import DeleteVesselRequest
from .types.service import DropVesselsRequest
from .types.service import EmptyParams
from .types.service import EmptyResponse
from .types.service import Fleet
from .types.service import Fleets
from .types.service import GetFleetLiveMapRequest
from .types.service import GetFleetLiveMapResponse
from .types.service import GetFleetRequest
from .types.service import ListVesselsRequest
from .types.service import ListVesselsWithStatusRequest
from .types.service import RenameFleetRequest
from .types.service import ShareFleetRequest
from .types.service import UpdateVesselParams
from .types.service import UpdateVesselRequest
from .types.service import Vessel
from .types.service import VesselParams
from .types.service import VesselSpeedEvent
from .types.service import VesselStatus
from .types.service import Vessels


__all__ = (
    'AddVesselRequest',
    'BatchVesselsRequest',
    'CreateFleetRequest',
    'DeleteFleetRequest',
    'DeleteVesselRequest',
    'DropVesselsRequest',
    'EmptyParams',
    'EmptyResponse',
    'Fleet',
    'Fleets',
    'GetFleetLiveMapRequest',
    'GetFleetLiveMapResponse',
    'GetFleetRequest',
    'ListVesselsRequest',
    'ListVesselsWithStatusRequest',
    'RenameFleetRequest',
    'ShareFleetRequest',
    'UpdateVesselParams',
    'UpdateVesselRequest',
    'Vessel',
    'VesselParams',
    'VesselSpeedEvent',
    'VesselStatus',
    'Vessels',
'FleetManagementServiceClient',
)

==> oceanbolt.sdk-0.2.5.tar.gz: oceanbolt.sdk-0.2.5/oceanbolt/com/fleetmanagement_v3/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .services.fleet_management_service import FleetManagementServiceClient
from .types.service import AddVesselRequest
from .types.service import BatchVesselsRequest
from .types.service import CreateFleetRequest
from .types.service import DeleteFleetRequest
from .types.service import DeleteVesselRequest
from .types.service import DropVesselsRequest
from .types.service import EmptyParams
from .types.service import EmptyResponse
from .types.service import Fleet
from .types.service import Fleets
from .types.service import GetFleetLiveMapRequest
from .types.service import GetFleetLiveMapResponse
from .types.service import GetFleetRequest
from .types.service import ListVesselsRequest
from .types.service import ListVesselsWithStatusRequest
from .types.service import RenameFleetRequest
from .types.service import ShareFleetRequest
from .types.service import UpdateVesselParams
from .types.service import UpdateVesselRequest
from .types.service import Vessel
from .types.service import VesselParams
from .types.service import VesselStatus
from .types.service import VesselStoppageEvent
from .types.service import Vessels


__all__ = (
    'AddVesselRequest',
    'BatchVesselsRequest',
    'CreateFleetRequest',
    'DeleteFleetRequest',
    'DeleteVesselRequest',
    'DropVesselsRequest',
    'EmptyParams',
    'EmptyResponse',
    'Fleet',
    'Fleets',
    'GetFleetLiveMapRequest',
    'GetFleetLiveMapResponse',
    'GetFleetRequest',
    'ListVesselsRequest',
    'ListVesselsWithStatusRequest',
    'RenameFleetRequest',
    'ShareFleetRequest',
    'UpdateVesselParams',
    'UpdateVesselRequest',
    'Vessel',
    'VesselParams',
    'VesselStatus',
    'VesselStoppageEvent',
    'Vessels',
'FleetManagementServiceClient',
)
